export const isValidEmail = (value) => {
    if (typeof value !== "string" || !value) {
        return false;
    }
    const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
    return emailRegex.test(value);
};
export const min = (minValue) => (value) => {
    if (typeof value === "number") {
        return value >= minValue;
    }
    else if (typeof value === "string") {
        return value.length >= minValue;
    }
    return false;
};
export const max = (maxValue) => (value) => {
    if (typeof value === "number") {
        return value <= maxValue;
    }
    else if (typeof value === "string") {
        return value.length <= maxValue;
    }
    return false;
};
export const validateStrongPassword = (password) => {
    const strongPasswordRegex = /^(?=.*[a-z])(?=.*[A-Z])(?=.*\d)(?=.*[@$!%*?&])[A-Za-z\d@$!%*?&]{8,}$/;
    return strongPasswordRegex.test(password);
};
export const required = (value) => {
    return value !== null && value !== undefined && value !== "";
};
export const equalTo = (compareValue) => (value) => {
    return value === compareValue;
};
export const isNumber = (value) => {
    return typeof value === "number";
};
export const isBoolean = (value) => {
    return typeof value === "boolean";
};
export const isString = (value) => {
    return typeof value === "string";
};
export const pattern = (regex) => (value) => {
    if (typeof value !== "string") {
        return false;
    }
    return regex.test(value);
};
export const optional = (validator) => (value) => {
    if (value === null || value === undefined || value === "") {
        return true;
    }
    return validator(value);
};
export const isTrue = (value) => {
    return value === true;
};
export const isFalse = (value) => {
    return value === false;
};
export const isImage = (value) => {
    console.log(value);
    if (value instanceof File) {
        return value.type.includes("image");
    }
    return false;
};
//# sourceMappingURL=formValid.js.map